@@ -29,4 +29,18 @@ class FileLogger(Logger):
         super().__init__(name, level)
 
         fh = logging.FileHandler('%s.log' % name, 'w')
-        self.logger.addHandler(fh)
\ No newline at end of file
+        self.logger.addHandler(fh)
+
+def get_logging_level_from_string(inLevel):
+    if inLevel == "debug":
+        return logging.DEBUG
+    elif inLevel == "info":
+        return logging.INFO
+    elif inLevel == "warning":
+        return logging.WARNING
+    elif inLevel == "error":
+        return logging.ERROR
+    elif inLevel == "critical":
+        return loggin.CRITICAL
+
+    return logging.NOTSET
\ No newline at end of file
