@@ -33,9 +33,9 @@ def get_cache_directory(level=logging.DEBUG):
     if platform.system().lower() == "windows":
         return os.path.expandvars(R"%localappdata%")
     elif platform.system().lower() == "linux":
-        return "~/.cache"
+        return os.path.expanduser(r"~")
     elif platform.system().lower() == "darwin":
-        return "~/Library/"
+        return os.path.expanduser(r"~")
     
     logger.error("Could not determine platform")
     return ""
@@ -59,7 +59,7 @@ def get_root_directory(level=logging.DEBUG):
     logger.addHandler(logging.StreamHandler())
 
     logger.debug("Looking for root directory ... ( dependant on the git directory )")
-    root_directory = os.path.normpath(os.path.join(get_git_directory(), os.pardir))
+    root_directory = os.path.normpath(os.path.join(get_git_directory(level), os.pardir))
 
     logger.info("Root directory found: " + root_directory)
     return root_directory
